@@ -40,7 +40,7 @@ class SessionStore(SessionBase):
 
     def create(self):
         while True:
-            self.session_key = self._get_new_session_key()
+            self._session_key = self._get_new_session_key()
             try:
                 # Save immediately to ensure we have a unique entry in the
                 # database.
@@ -63,6 +63,7 @@ class SessionStore(SessionBase):
                         session._session_cache = {}
                     session._session_cache.update(self._session_cache)
                 session.save(*a, **kw)
+                self._session_key = session.session_key
             except:
                 # Try another backend
                 continue
